(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{31:function(e,t,n){e.exports=n(41)},41:function(e,t,n){"use strict";n.r(t);var a=n(4),c=n.n(a),o=n(26),i=n.n(o),s=n(9),l=n(0),r=n(1),u=n(2),p=n(3),d=n(15),m=n(53),h=function(e){Object(u.a)(n,e);var t=Object(p.a)(n);function n(e){var a;Object(r.a)(this,n),(a=t.call(this,e)).render=function(){var e=a.props.args.choices,t=a.props.args.options||{},n=a.state.selectedChoice,o={padding:"0.5em",marginBottom:"0.5em"},i=Object(s.a)(Object(s.a)({},o),{},{width:"100%"}),l=Object(s.a)(Object(s.a)({},o),{},{flex:1}),r={},u={};return"horizontal"===t.orientation?(r={display:"flex",flexDirection:"row",alignItems:"center",justifyContent:"space-evenly",columnGap:"0.5em"},u=l):(r={display:"flex",flexDirection:"column",justifyContent:"space-evenly",alignItems:"flex-start"},u=i),c.a.createElement("div",{style:r},e.map((function(e,t){return c.a.createElement(m.a,{color:"success",variant:n==e?"contained":"outlined",key:t,style:u,onClick:function(){return a.handleChoiceClick(e)}},e)})))},a.handleChoiceClick=function(e){a.setState({selectedChoice:e}),a.setState((function(t){return{selectedChoice:e}}),(function(){return d.a.setComponentValue(a.state.selectedChoice)}))};var o=a.props.args.choices,i=a.props.args.options||{};return void 0!==i.default_index?(a.state={selectedChoice:o[i.default_index]},d.a.setComponentValue(a.state.selectedChoice)):(a.state={selectedChoice:""},d.a.setComponentValue(a.state.selectedChoice)),a}return Object(l.a)(n)}(d.b),f=Object(d.c)(h);i.a.render(c.a.createElement(c.a.StrictMode,null,c.a.createElement(f,null)),document.getElementById("root"))}},[[31,1,2]]]);
//# sourceMappingURL=main.a3dcf2e2.chunk.js.map